@@ -14,11 +14,11 @@ BEGIN {
         century gMonthDay gDay duration recurringDuration anyURI
         language integer nonPositiveInteger negativeInteger long int short byte
         nonNegativeInteger unsignedLong unsignedInt unsignedShort unsignedByte
-        positiveInteger date time dateTime
+        positiveInteger date time
     )) {
-        my $name = 'as_' . $method; 
-        *$name = sub { $_[1] }; 
+        my $name = 'as_' . $method;
+        *$name = sub { $_[1] };
     }
 }
 
-1;
\ No newline at end of file
+1;
